import { StorageHelper } from '~/helpers'

const state = {
  isAuthenticated: !!StorageHelper.getLocalToken(),
  token: StorageHelper.getLocalToken(),
  loading: false,
  errors: {},
}

const getters = {
  isAuthenticated: (state) => state.isAuthenticated,
  token: (state) => state.token,
  loading: (state) => state.loading,
}

const actions = {
  login({ commit, dispatch }, { accessToken }) {
    StorageHelper.storeLocalToken(accessToken)
    commit('login', accessToken)
  },
  logout({ commit }) {
    commit('logout')
    StorageHelper.removeLocalToken()
  },
}

const mutations = {
  login(state, token) {
    state.isAuthenticated = true
    state.token = token
  },
  logout(state) {
    state.isAuthenticated = false
    state.token = ''
  },
  loading(state, status) {
    state.loading = status
  },
}

export default {
  namespaced: true,
  state,
  getters,
  actions,
  mutations,
}
